/*********************************************************

INCLUDE FILE: language.agc
  by Steve Vink, April 2015
  Use permitted for all purposes, commercial and personal

	This file contains functions to facilitate multi-language projects

// Project: Language 
// Created: 2015-03-17


**********************************************************/

//*********************************************************
//  TYPE: 	tLanguage
//	      	used for the storage of language-specific parameters
//    
//			folder is the language folder
//			currentLanguage is the selected language
//			Path is the path to the language files
//			language[] is the list of languages
//*********************************************************

type tLanguage
	folder as string
    currentLanguage as string
    path as string
    language as string[]
endtype

global gLanguage as tLanguage


//*********************************************************
function initLanguage(folder$ as String, language$ as String)
//*********************************************************
//	Initialise the language subsystem
//
//  folder$ is the media subfolder where all of the 
//  language files are stored e.g if folder$ = "language"
//  then the structure may be:
//  
//	media/language/English
//  media/language/French
//  media/langauge/Spanish
//
// 	Normally, this value is hard-code, or stored in a parameter file
//
//	Language$ is the default language
//	This should be retrieved from a parameter file
//  You must always have a default language, in case no language is selected
//*********************************************************

	global thisFolder$ as String
	
	gLanguage.folder = folder$
	
	//get languages by iterating through folders
	//Save current folder and set to langauge folder
	savedFolder$ = GetFolder()
	SetFolder(gLanguage.folder)
	
	//Iterate through folders and save folder names
	thisFolder$ = GetFirstFolder()
	while thisFolder$ <> ""
		gLanguage.language.length = gLanguage.language.length + 1
		gLanguage.language[gLanguage.language.length] = thisFolder$
		thisFolder$ = GetNextFolder()
	endwhile

	// Reset current folder
	SetFolder("")
	SetFolder(savedFolder$)

	// Load the default Languge
	setLanguage(language$)

endfunction

//*********************************************************
function getLanguages(arrLanguage ref as string[])
//*********************************************************
//	get the list of Languages
//
//	Because you are likely to want to refer to the list of languages
//  to perform actions (e.g create a menu of languages) the
//  function accepts the array that you want to store
//	the languages in. This is passed by reference
//
//	The process of copying from one array to another may
//	seem unnecessary, but in order to encapsulate functionality
//	and protect the integrity of the data, you should only
//	access the data through functions and not directly.
// 
//*********************************************************

	arrLanguage.length = gLanguage.language.length
	for n = 0 to gLanguage.language.length
		arrLanguage[n] = gLanguage.language[n]
	next n

endfunction

//*********************************************************
function setLanguage(language$)
//*********************************************************
//	sets the current language
//
//	This function sets a new language and reloads the language data
// 	New requests for language phrases will return the new language version
//
//	The function assumes that you have queried the languages available
// 	and requested a valid language
//*********************************************************
	
	gLanguage.currentLanguage = language$
	gLanguage.path = "\media\" + gLanguage.folder + "\" + gLanguage.currentLanguage
	
	// Now open the language file and load the phrases
	// This uses the Parameter functionality and all of the 
	// existing logic to validate the data
	
	LoadParms(gLanguage.path + "\" + gLanguage.currentLanguage + ".txt", "language")
	
endfunction


//*********************************************************
function getLanguagePhrase(phraseId$)
//*********************************************************
//	gets a phrase from the current language
//
//*********************************************************

	phrase$ = getParm(phraseId$, "language")

endfunction phrase$
