/*********************************************************

Tutorial Project: Language
  by Steve Vink, March 2015
  Use permitted for all purposes, commercial and personal

  This project is a demonstration of how to use
  the language.agc include file. Do not include this 
  file in your own projects, include only:
  
  language.agc
  parameters.agc
  
  The main.agc file is a practical demonstration of the use of
  the language functionality.

********************************************************/

// Include the parameter and language file module
#include "parameters.agc"
#include "language.agc"

//Create a type to hold our demo text
type tText
	id
	text as string
endtype

// make an array from the type
global arrTxt as tText[4]

// Make an array for the language buttons
global arrLanguageButton as string[]

// set window properties
SetWindowTitle( "Parameters" )
SetVirtualResolution(1024,768)

// set display properties
SetOrientationAllowed( 1, 1, 1, 1 )

iFont = LoadImage("Avenir.png")
SetTextDefaultFontImage(iFont)

//Initialise parameter system
// This is required whenever you use the module
initParms(10)

// Load the parameters from file
// using functionality from the parameters module
// This example loads 2 files, with 2 different identifiers
	LoadParms("parameters.ini", "main")
	LoadParms("setup.ini", "setup")

// Initialise the language subsystem
// Get the current language from the setup.ini parameters
	initLanguage("Language", getParm("language","setup"))


// Get the Phrases and display on screen. The phrase names are the same for any language
//Create some text objects to display our parameters

	for n = 1 to 3
		arrTxt[n].id = CreateText("")
	next n
	setApplicationPhrases()

//Create a tween for aesthetics
	tweenTxt = CreateTweenText(0.5)
	SetTweenTextAlpha(tweenTxt,0,255,5)
	
// Create Text for each language. We will click these to change the language
// Start by retrieving the array of languages
	getLanguages(arrLanguageButton)
	for n = 0 to arrLanguageButton.length
		CreateText(n+1, arrLanguageButton[n])
		SetTextSize(n+1, 40)
		SetTextColor(n+1,150,150,255,255)
		SetTextAlignment(n+1,1)
		SetTextColorAlpha(n+1,0)
		SetTextPosition(n+1, GetVirtualWidth()/2, (getVirtualHeight()/2) + (n * 60))
		PlayTweenText(tweenTxt,n+1,3 + (n * 0.5))
	next n


	//Display the text using the fade tween
	displayText(tweenTxt)

	do
		//Check if a selection has been made
		if GetPointerReleased() = 1
			for n = 0 to arrLanguageButton.length
				hit = GetTextHitTest(n+1, GetPointerX(), GetPointerY())
				if hit = 1
					setLanguage(GetTextString(n+1))
					setApplicationPhrases()
					displayText(tweenTxt)
				endif
			next n
		endif
		
		UpdateAllTweens(GetFrameTime())
		Sync()
	loop

end

//*************************************************************
function setApplicationPhrases()
//*************************************************************
//	This function retreives the screen phrases 
//	At this stage, language is irrelevant, it will retrieve the current language
//************************************************************//
	
	arrTxt[1].text = getLanguagePhrase("welcome")
	arrTxt[2].text = getLanguagePhrase("advantage")
	arrTxt[3].text = getLanguagePhrase("instruction")

	for n = 1 to 3
		SetTextString(arrTxt[n].id, arrTxt[n].text)
	next n

endfunction


//*************************************************************
function displayText(tween)
//*************************************************************
	for n = 1 to 3
		SetTextSize(arrTxt[n].id, 40)
		SetTextAlignment(arrTxt[n].id,1)
		SetTextColor(arrTxt[n].id,255,255,192,255)
		SetTextColorAlpha(arrTxt[n].id,0)
		SetTextPosition(arrTxt[n].id, GetVirtualWidth()/2, 100 + ((n-1)*60))
		PlayTweenText(tween,arrTxt[n].id,n * 0.5)
	next n
endfunction
